<?php
/*********************************************************************************
** The contents of this file are subject to the vtiger CRM Public License Version 1.0
* ("License"); You may not use this file except in compliance with the License
* The Original Code is:  vtiger CRM Open Source
* The Initial Developer of the Original Code is vtiger.
* Portions created by vtiger are Copyright (C) vtiger.
* All Rights Reserved.
*
********************************************************************************/


$mod_strings = Array(
// added for 5.0 beta
'LBL_BOOKMARKED_URL'=>"BookMarked URL's",
'LBL_MANAGE_BOOKMARKS'=>'Manage Bookmarks',
'LBL_BOOKMARK_LIST'=>'Bookmark List',
'LBL_MY_BOOKMARKS'=>'My Bookmarks',
'LBL_NEW_BOOKMARK'=>'New Bookmark',
'LBL_BOOKMARK'=>'Bookmark',
'LBL_NAME'=>'Name :',
'LBL_URL'=>'URL :',
'LBL_ADD'=>'Add',
'LBL_SNO'=>'#',
'LBL_BOOKMARK_NAME_URL'=>'Bookmark Name &amp; URL',
'LBL_TOOLS'=>'Tools',
'LBL_MANAGE_SITES'=>'Manage Sites',
'LBL_MY_SITES'=>'Sites',

// Added/Updated for vtiger CRM 5.0.4
//added as an enhancement
'LBL_SET_DEFAULT_BUTTON'=>'Set As Default',
);
?>
